@@ -13,4 +13,6 @@ admin.site.register(models.Sheet)
 admin.site.register(models.Map)
 admin.site.register(models.ProgressCounter)
 admin.site.register(models.ProgressLog)
-admin.site.register(models.Settings)
\ No newline at end of file
+admin.site.register(models.Settings)
+admin.site.register(models.PushSubscription)
+admin.site.register(models.MoodLog)
\ No newline at end of file
